@@ -262,13 +262,15 @@ def rds(ctx, bucket, key, password=None, profile=None):
         if ([io.file]::exists($p)) {'{'}
             $acl = get-acl -path $p
             $acl.addaccessrule($rule)
-            echo "modifying acl on $p"
+            echo 'modifying acl'
+            echo $p
             set-acl $p $acl
         {'}'}
         if ([io.file]::exists($q)) {'{'}
             $acl = get-acl -path $q
             $acl.addaccessrule($rule)
-            echo "modifying acl on $q"
+            echo 'modifying acl'
+            echo $q
             set-acl $q $acl
         {'}'}
         """
@@ -304,20 +306,21 @@ def winrm(ctx, bucket, key, password=None, profile=None):
         $rule = new-object security.accesscontrol.filesystemaccessrule 'NETWORK SERVICE', 'Read', allow
         foreach ($x in @($p, $q)) {'{'}
             if ([io.file]::exists($p)) {'{'}
+                echo 'modifying acl'
                 $acl = get-acl -path $x
                 $acl.addaccessrule($rule)
-                echo "modifying acl on $x"
+                echo $x
                 set-acl $x $acl
             {'}'}
         {'}'}
         $valueset = @{'{'}
-            Hostname = $cert.subject.split("=", 2)[1]
+            Hostname = $cert.subject.split('=', 2)[1]
             CertificateThumbprint = $thumbprint
         {'}'}
 
         $selectorset = @{'{'}
-            Transport = "HTTPS"
-            Address = "*"
+            Transport = 'HTTPS'
+            Address = '*'
         {'}'}
         Remove-WSManInstance -ResourceURI 'winrm/config/Listener' -SelectorSet $selectorset
         New-WSManInstance -ResourceURI 'winrm/config/Listener' -SelectorSet $selectorset -ValueSet $valueset
